@@ -32,10 +32,7 @@ from typing import TYPE_CHECKING, Any, cast
 
 from simple_salesforce import Salesforce, api
 
-try:
-    from airflow.sdk import BaseHook
-except ImportError:
-    from airflow.hooks.base import BaseHook  # type: ignore[attr-defined,no-redef]
+from airflow.providers.salesforce.version_compat import BaseHook
 
 if TYPE_CHECKING:
     import pandas as pd
